@@ -14,4 +14,4 @@ result = rowan.submit_protein_cofolding_workflow(
     name="Torcetrapib Cofolding",
 )
 
-print(result)
+print(result.wait_for_result().fetch_latest(in_place=True))
