@@ -1,6 +1,6 @@
 import time
 from datetime import datetime
-from typing import Any, Self, TypeAlias
+from typing import Any, Literal, Self, TypeAlias
 
 import stjames
 from pydantic import BaseModel, Field
@@ -493,6 +493,7 @@ def submit_conformer_search_workflow(
 
 def submit_solubility_workflow(
     initial_smiles: str,
+    solubility_method: Literal["fastsolv", "kingfisher", "esol"] = "fastsolv",
     solvents: list[str] | None = None,
     temperatures: list[float] | None = None,
     name: str = "Solubility Workflow",
@@ -502,6 +503,7 @@ def submit_solubility_workflow(
     """
     Submits a solubility workflow to the API.
 
+    :param solubility_method: The name of the desired model for solubility prediction.
     :param initial_smiles: The smiles of the molecule to calculate the solubility of.
     :param solvents: The list of solvents to use for the calculation.
     :param temperatures: The list of temperatures to use for the calculation.
@@ -520,6 +522,7 @@ def submit_solubility_workflow(
 
     workflow = stjames.SolubilityWorkflow(
         initial_smiles=initial_smiles,
+        solubility_method=solubility_method,
         solvents=solvents,
         temperatures=temperatures,
     )
@@ -857,7 +860,8 @@ def submit_macropka_workflow(
     max_pH: int = 14,
     min_charge: int = -2,
     max_charge: int = 2,
-    compute_solvation_energy: bool = True,
+    compute_solvation_energy: bool = False,
+    compute_aqueous_solubility: bool = False,
     name: str = "Macropka Workflow",
     folder_uuid: str | None = None,
     max_credits: int | None = None,
@@ -870,6 +874,7 @@ def submit_macropka_workflow(
     :param max_pH: The maximum pH to use in the macropka workflow.
     :param min_charge: The minimum charge to use in the macropka workflow.
     :param max_charge: The maximum charge to use in the macropka workflow.
+    :param compute_aqueous_solubility: Whether to compute the aqueous solubility for each pH.
     :param compute_solvation_energy: Whether to compute the solvation energy.
     :param name: The name of the workflow.
     :param folder_uuid: The UUID of the folder to store the workflow in.
@@ -885,6 +890,7 @@ def submit_macropka_workflow(
         min_charge=min_charge,
         max_charge=max_charge,
         compute_solvation_energy=compute_solvation_energy,
+        compute_aqueous_solubility=compute_aqueous_solubility,
     )
 
     data = {
@@ -1021,8 +1027,9 @@ def submit_docking_workflow(
     protein: str | Protein,
     pocket: list[list[float]],
     initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol | None = None,
-    do_csearch: bool = True,
-    do_optimization: bool = True,
+    do_csearch: bool = False,
+    do_optimization: bool = False,
+    do_pose_refinement: bool = False,
     name: str = "Docking Workflow",
     folder_uuid: str | None = None,
     max_credits: int | None = None,
@@ -1034,6 +1041,7 @@ def submit_docking_workflow(
     :param initial_molecule: The initial molecule to be docked
     :param do_csearch: Whether to perform a conformational search on the ligand.
     :param do_optimization: Whether to perform an optimization on the ligand.
+    :param do_pose_refinement: Whether or not to optimize output poses.
     :param name: The name of the workflow.
     :param folder_uuid: The UUID of the folder to place the workflow in.
     :param max_credits: The maximum number of credits to use for the workflow.
@@ -1055,6 +1063,7 @@ def submit_docking_workflow(
         pocket=pocket,
         do_csearch=do_csearch,
         do_optimization=do_optimization,
+        do_pose_refinement=do_pose_refinement
     )
 
     data = {
@@ -1070,3 +1079,108 @@ def submit_docking_workflow(
         response = client.post("/workflow", json=data)
         response.raise_for_status()
         return Workflow(**response.json())
+
+
+def submit_ion_mobility_workflow(
+    initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
+    temperature: float = 300,
+    protonate: bool = False,
+    do_csearch: bool = True,
+    do_optimization: bool = True,
+    name: str = "Ion-Mobility Workflow",
+    folder_uuid: str | None = None,
+    max_credits: int | None = None,
+) -> Workflow:
+    """
+    Submits an ion-mobility workflow to the API.
+
+    :param initial_molecule: The molecule used in the scan.
+    :param temperature: The temperature at which to predict CCS values.
+    :param protonate: Whether or not to automatically detect protonation site.
+        If `True`, every basic site will be protonated and values returned for the most stable.
+    :param do_csearch: Whether to perform a conformational search on the molecule.
+    :param do_optimization: Whether to perform an optimization on the molecule.
+    :param name: The name of the workflow.
+    :param folder_uuid: The UUID of the folder to store the workflow in.
+    :param max_credits: The maximum number of credits to use for the workflow.
+    :return: A Workflow object representing the submitted workflow.
+    :raises requests.HTTPError: if the request to the API fails.
+    """
+    if isinstance(initial_molecule, StJamesMolecule):
+        initial_molecule = initial_molecule.model_dump()
+    elif isinstance(initial_molecule, RdkitMol):
+        initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
+
+    workflow = stjames.IonMobilityWorkflow(
+        initial_molecule=initial_molecule,
+        temperature=temperature,
+        protonate=protonate,
+        do_csearch=do_csearch,
+        do_optimization=do_optimization,
+    )
+
+    data = {
+        "name": name,
+        "folder_uuid": folder_uuid,
+        "workflow_type": "ion_mobility",
+        "workflow_data": workflow.model_dump(),
+        "initial_molecule": initial_molecule,
+        "max_credits": max_credits,
+    }
+
+    with api_client() as client:
+        response = client.post("/workflow", json=data)
+        response.raise_for_status()
+        return Workflow(**response.json())
+
+
+def submit_nmr_workflow(
+    initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
+    solvent: str | None = "chloroform",
+    do_csearch: bool = True,
+    do_optimization: bool = True,
+    name: str = "NMR Workflow",
+    folder_uuid: str | None = None,
+    max_credits: int | None = None,
+) -> Workflow:
+    """
+    Submits an NMR-prediction workflow to the API.
+
+    :param initial_molecule: The molecule used in the scan.
+    :param solvent: The solvent in which to compute NMR spectra.
+    :param do_csearch: Whether to perform a conformational search on the input structure.
+    :param do_optimization: Whether to perform an optimization on the input structure.
+    :param name: The name of the workflow.
+    :param folder_uuid: The UUID of the folder to store the workflow in.
+    :param max_credits: The maximum number of credits to use for the workflow.
+    :return: A Workflow object representing the submitted workflow.
+    :raises requests.HTTPError: if the request to the API fails.
+    """
+    if isinstance(initial_molecule, StJamesMolecule):
+        initial_molecule = initial_molecule.model_dump()
+    elif isinstance(initial_molecule, RdkitMol):
+        initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
+
+    workflow_data = {"initial_molecule": initial_molecule, "solvent": solvent}
+
+    if not do_csearch:
+        workflow_data["conf_gen_settings"] = None
+
+    if not do_optimization:
+        workflow_data["multistage_opt_settings"] = None
+
+    workflow = stjames.NMRSpectroscopyWorkflow.model_validate(workflow_data)
+
+    data = {
+        "name": name,
+        "folder_uuid": folder_uuid,
+        "workflow_type": "nmr",
+        "workflow_data": workflow.model_dump(serialize_as_any=True),
+        "initial_molecule": initial_molecule,
+        "max_credits": max_credits,
+    }
+
+    with api_client() as client:
+        response = client.post("/workflow", json=data)
+        response.raise_for_status()
+        return Workflow(**response.json())
